=== modified file 'NEWS'
--- NEWS	2008-06-06 18:04:45 +0000
+++ NEWS	2008-05-23 13:14:58 +0000
@@ -1,9 +1,5 @@
 0.95.0	UNRELEASED
 
- UI
-
-  * Added Refresh menu option with F5 keyboard shortcut (Russ Brown)
-
  BUG FIXES
 
   * Replace _() calls by _i18n() calls. (Vincent Ladeuil, #187283)

=== modified file '__init__.py'
--- __init__.py	2008-06-27 16:53:56 +0000
+++ __init__.py	2008-05-22 03:43:15 +0000
@@ -22,6 +22,7 @@
 gcommit           GTK+ commit dialog.
 gconflicts        GTK+ conflicts. 
 gdiff             Show differences in working tree in a GTK+ Window. 
+ghandle-patch     Display and optionally merge a merge directive or patch.
 ginit             Initialise a new branch.
 gmissing          GTK+ missing revisions dialog. 
 gpreferences      GTK+ preferences dialog. 
@@ -119,22 +120,21 @@
     return None
 
 
-def open_display():
-    pygtk = import_pygtk()
-    try:
-        import gtk
-    except RuntimeError, e:
-        if str(e) == "could not open display":
-            raise NoDisplayError
-    set_ui_factory()
-    return gtk
- 
-
 class GTKCommand(Command):
     """Abstract class providing GTK specific run commands."""
 
+    def open_display(self):
+        pygtk = import_pygtk()
+        try:
+            import gtk
+        except RuntimeError, e:
+            if str(e) == "could not open display":
+                raise NoDisplayError
+        set_ui_factory()
+        return gtk
+
     def run(self):
-        open_display()
+        self.open_display()
         dialog = self.get_gtk_dialog(os.path.abspath('.'))
         dialog.run()
 
@@ -168,7 +168,7 @@
 
     def run(self, location="."):
         (br, path) = branch.Branch.open_containing(location)
-        open_display()
+        self.open_display()
         from push import PushDialog
         dialog = PushDialog(br.repository, br.last_revision(), br)
         dialog.run()
@@ -286,7 +286,7 @@
     aliases = ["gblame", "gpraise"]
     
     def run(self, filename, all=False, plain=False, line='1', revision=None):
-        gtk = open_display()
+        gtk = self.open_display()
 
         try:
             line = int(line)
@@ -345,7 +345,7 @@
 
     def run(self, filename=None):
         import os
-        open_display()
+        self.open_display()
         from commit import CommitDialog
         from bzrlib.errors import (BzrCommandError,
                                    NotBranchError,
@@ -386,7 +386,7 @@
 
     def run(self, path='.', revision=None):
         import os
-        gtk = open_display()
+        gtk = self.open_display()
         from status import StatusDialog
         (wt, wt_path) = workingtree.WorkingTree.open_containing(path)
         
@@ -410,7 +410,7 @@
     """
     def run(self):
         (br, path) = branch.Branch.open_containing(".")
-        gtk = open_display()
+        gtk = self.open_display()
         from bzrlib.plugins.gtk.mergedirective import SendMergeDirectiveDialog
         from StringIO import StringIO
         dialog = SendMergeDirectiveDialog(br)
@@ -432,7 +432,7 @@
     """
     def run(self):
         (wt, path) = workingtree.WorkingTree.open_containing('.')
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.conflicts import ConflictsDialog
         dialog = ConflictsDialog(wt)
         dialog.run()
@@ -443,7 +443,7 @@
 
     """
     def run(self):
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.preferences import PreferencesWindow
         dialog = PreferencesWindow()
         dialog.run()
@@ -487,7 +487,7 @@
 
 class cmd_ginit(GTKCommand):
     def run(self):
-        open_display()
+        self.open_display()
         from initialize import InitDialog
         dialog = InitDialog(os.path.abspath(os.path.curdir))
         dialog.run()
@@ -497,7 +497,7 @@
     def run(self):
         br = branch.Branch.open_containing('.')[0]
         
-        gtk = open_display()
+        gtk = self.open_display()
         from tags import TagsWindow
         window = TagsWindow(br)
         window.show()
@@ -534,7 +534,7 @@
 
     def run(self):
         from notify import NotifyPopupMenu
-        gtk = open_display()
+        gtk = self.open_display()
         menu = NotifyPopupMenu()
         icon = gtk.status_icon_new_from_file(icon_path("bzr-icon-64.png"))
         icon.connect('popup-menu', menu.display)
@@ -692,6 +692,44 @@
 register_command(cmd_test_gtk)
 
 
+class cmd_ghandle_patch(GTKCommand):
+    """Display a patch or merge directive, possibly merging.
+
+    This is a helper, meant to be launched from other programs like browsers
+    or email clients.  Since these programs often do not allow parameters to
+    be provided, a "handle-patch" script is included.
+    """
+
+    takes_args = ['path']
+
+    def run(self, path):
+        try:
+            from bzrlib.plugins.gtk.diff import (DiffController,
+                                                 MergeDirectiveController)
+            if path == '-':
+                lines = sys.stdin.readlines()
+            else:
+                lines = open(path, 'rb').readlines()
+            lines = [l.replace('\r\n', '\n') for l in lines]
+            try:
+                directive = merge_directive.MergeDirective.from_lines(lines)
+            except errors.NotAMergeDirective:
+                controller = DiffController(path, lines)
+            else:
+                controller = MergeDirectiveController(path, directive)
+            window = controller.window
+            window.show()
+            gtk = self.open_display()
+            window.connect("destroy", gtk.main_quit)
+        except Exception, e:
+            from dialog import error_dialog
+            error_dialog('Error', str(e))
+            raise
+        gtk.main()
+
+
+register_command(cmd_ghandle_patch)
+
 
 import gettext
 gettext.install('olive-gtk')

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-28 15:45:39 +0000
+++ branchview/treeview.py	2008-05-05 18:16:46 +0000
@@ -3,7 +3,7 @@
 
 """
 
-__copyright__ = "Copyright © 2005 Canonical Ltd."
+__copyright__ = "Copyright  2005 Canonical Ltd."
 __author__    = "Daniel Schierbeck <daniel.schierbeck@gmail.com>"
 
 import sys
@@ -286,7 +286,7 @@
 
         self.branch.lock_read()
         (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
-                                                        (self.start,) , # Sequence of start revisions
+                                                        self.start,
                                                         self.maxnum, 
                                                         broken_line_length,
                                                         show_graph,
@@ -339,7 +339,7 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.revno_column = gtk.TreeViewColumn("Revision No")
-        self.revno_column.set_resizable(False)
+        self.revno_column.set_resizable(True)
         self.revno_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.revno_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.revno_column.pack_start(cell, expand=True)
@@ -348,9 +348,9 @@
 
         self.graph_cell = CellRendererGraph()
         self.graph_column = gtk.TreeViewColumn()
-        self.graph_column.set_resizable(False)
+        self.graph_column.set_resizable(True)
         self.graph_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.graph_column.pack_start(self.graph_cell, expand=True)
+        self.graph_column.pack_start(self.graph_cell, expand=False)
         self.graph_column.add_attribute(self.graph_cell, "node", treemodel.NODE)
         self.graph_column.add_attribute(self.graph_cell, "tags", treemodel.TAGS)
         self.graph_column.add_attribute(self.graph_cell, "in-lines", treemodel.LAST_LINES)
@@ -361,8 +361,7 @@
         cell.set_property("width-chars", 65)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.summary_column = gtk.TreeViewColumn("Summary")
-        self.summary_column.set_resizable(False)
-        self.summary_column.set_expand(True)
+        self.summary_column.set_resizable(True)
         self.summary_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.summary_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.summary_column.pack_start(cell, expand=True)
@@ -373,9 +372,9 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.committer_column = gtk.TreeViewColumn("Committer")
-        self.committer_column.set_resizable(False)
+        self.committer_column.set_resizable(True)
         self.committer_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.committer_column.set_fixed_width(200)
+        self.committer_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.committer_column.pack_start(cell, expand=True)
         self.committer_column.add_attribute(cell, "text", treemodel.COMMITTER)
         self.treeview.append_column(self.committer_column)
@@ -385,9 +384,9 @@
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.date_column = gtk.TreeViewColumn("Date")
         self.date_column.set_visible(False)
-        self.date_column.set_resizable(False)
+        self.date_column.set_resizable(True)
         self.date_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.date_column.set_fixed_width(130)
+        self.date_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.date_column.pack_start(cell, expand=True)
         self.date_column.add_attribute(cell, "text", treemodel.TIMESTAMP)
         self.treeview.append_column(self.date_column)

=== modified file 'bzr-gtk.applications'
--- bzr-gtk.applications	2008-06-27 16:55:09 +0000
+++ bzr-gtk.applications	2008-04-02 18:01:18 +0000
@@ -1,5 +1,5 @@
 bzr-gtk-patch
-	command=bzr-handle-patch
+	command="bzr handle-patch"
 	name=Bazaar
 	can_open_multiple_files=false
 	expects_uris=false

=== modified file 'commit.py'
--- commit.py	2008-06-07 09:00:24 +0000
+++ commit.py	2008-05-05 18:16:46 +0000
@@ -303,9 +303,6 @@
                             gtk.gdk.CONTROL_MASK, 0, self._on_accel_next)
         self.add_accel_group(group)
 
-        # ignore the escape key (avoid closing the window)
-        self.connect_object('close', self.emit_stop_by_name, 'close')
-
     def _construct_left_pane(self):
         self._left_pane_box = gtk.VBox(homogeneous=False, spacing=5)
         self._construct_file_list()

=== renamed file 'bzr-handle-patch' => 'handle-patch'
--- bzr-handle-patch	2008-06-27 16:53:56 +0000
+++ handle-patch	2008-02-23 06:39:14 +0000
@@ -1,39 +1,2 @@
-#!/usr/bin/python
-
-from bzrlib import errors, merge_directive
-from bzrlib.plugin import load_plugins
-from bzrlib.plugins.gtk import open_display
-load_plugins()
-
-import sys
-
-if len(sys.argv) < 2:
-	print "Usage: handle-patch <path>"
-	sys.exit(1)
-
-
-path = sys.argv[1]
-
-try:
-	from bzrlib.plugins.gtk.diff import (DiffController,
-										 MergeDirectiveController)
-	if path == '-':
-		lines = sys.stdin.readlines()
-	else:
-		lines = open(path, 'rb').readlines()
-	lines = [l.replace('\r\n', '\n') for l in lines]
-	try:
-		directive = merge_directive.MergeDirective.from_lines(lines)
-	except errors.NotAMergeDirective:
-		controller = DiffController(path, lines)
-	else:
-		controller = MergeDirectiveController(path, directive)
-	window = controller.window
-	window.show()
-	gtk = open_display()
-	window.connect("destroy", gtk.main_quit)
-except Exception, e:
-	from dialog import error_dialog
-	error_dialog('Error', str(e))
-	raise
-gtk.main()
+#!/bin/sh
+/home/abentley/bin/bzr ghandle-patch "$@"

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2008-06-23 08:05:19 +0000
+++ olive/__init__.py	2008-05-05 18:16:46 +0000
@@ -446,7 +446,7 @@
     @show_bzr_error
     def on_entry_history_revno_key_press_event(self, widget, event):
         """ Key pressed handler for the history entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to load that specific revision
             # Emulate being remote, so inventory should be used
             path = self.get_path()
@@ -461,7 +461,7 @@
     
     def on_entry_location_key_press_event(self, widget, event):
         """ Key pressed handler for the location entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to jump
             self.on_button_location_jump_clicked(widget)
     

=== modified file 'olive/move.py'
--- olive/move.py	2008-06-28 16:59:50 +0000
+++ olive/move.py	2008-05-05 18:16:46 +0000
@@ -31,7 +31,7 @@
 
 from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog
-from bzrlib.plugins.gtk.errors import show_bzr_error
+from errors import show_bzr_error
 from guifiles import GLADEFILENAME
 
 

=== modified file 'revisionview.py'
--- revisionview.py	2008-06-24 10:34:38 +0000
+++ revisionview.py	2008-05-26 21:10:10 +0000
@@ -38,11 +38,10 @@
 PAGE_SIGNATURE = 2
 PAGE_BUGS = 3
 
+webbrowser.register('sensible-browser', None, webbrowser.GenericBrowser('sensible-browser'), -1)
+webbrowser.register('xdg-open', None, webbrowser.GenericBrowser('xdg-open'), -1)
 
 def _open_link(widget, uri):
-    for cmd in ['sensible-browser', 'xdg-open']:
-        if webbrowser._iscommand(cmd):
-            webbrowser._tryorder.insert(0, '%s "%%s"' % cmd)
     webbrowser.open(uri)
 
 gtk.link_button_set_uri_hook(_open_link)

=== modified file 'seahorse.py'
--- seahorse.py	2008-06-20 03:33:17 +0000
+++ seahorse.py	2008-05-29 09:48:48 +0000
@@ -28,20 +28,7 @@
 KEY_TYPE_OPENPGP = 'openpgp'
 KEY_TYPE_SSH = 'ssh'
 
-try:
-    bus = dbus.SessionBus()
-except dbus.exceptions.DBusException, e:
-    get_name = getattr(e, 'get_dbus_name', None)
-    if get_name is not None:
-        name = get_name()
-    else:
-        name = getattr(e, '_dbus_error_name', None)
-    # DBus sometimes fails like this, just treat it as if seahorse is not
-    # available rather than crashing.
-    if name == "org.freedesktop.DBus.Error.Spawn.ExecFailed":
-        raise ImportError
-    else:
-        raise
+bus = dbus.SessionBus()
 
 if hasattr(bus, 'list_activatable_names'):
     bus_names = bus.list_activatable_names()

=== modified file 'setup.py'
--- setup.py	2008-06-27 16:53:56 +0000
+++ setup.py	2008-05-04 20:23:56 +0000
@@ -96,7 +96,7 @@
     maintainer_email = "jelmer@samba.org",
     description = "GTK+ Frontends for various Bazaar commands",
     license = "GNU GPL v2 or later",
-    scripts=['olive-gtk', 'bzr-handle-patch'],
+    scripts=['olive-gtk'],
     package_dir = {
         "bzrlib.plugins.gtk": ".",
         "bzrlib.plugins.gtk.viz": "viz", 

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2008-06-10 15:25:47 +0000
+++ tests/test_commit.py	2008-05-04 13:11:26 +0000
@@ -81,8 +81,8 @@
         rev_id1 = tree.commit('one')
         tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
         rev_id2 = tree2.commit('two')
+        rev_id3 = tree2.commit('three')
         tree3 = tree2.bzrdir.sprout('tree3').open_workingtree()
-        rev_id3 = tree2.commit('three')
         rev_id4 = tree3.commit('four')
         rev_id5 = tree3.commit('five')
         tree.merge_from_branch(tree2.branch)
@@ -985,7 +985,8 @@
                          ], bencode.bdecode(file_info))
 
     def test_commit_unicode_messages(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         tree.branch.get_config().set_user_option('per_file_commits', 'true')

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2008-06-09 15:59:13 +0000
+++ tests/test_diff.py	2008-05-22 19:08:04 +0000
@@ -69,7 +69,8 @@
 class TestDiffView(tests.TestCaseWithTransport):
 
     def test_unicode(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         self.build_tree([u'tree/\u03a9'])

=== modified file 'ui.py'
--- ui.py	2008-06-20 03:36:30 +0000
+++ ui.py	2008-05-01 22:24:50 +0000
@@ -58,7 +58,7 @@
     def update(self, msg=None, current=None, total=None):
         if msg is not None:
             self.set_text(msg)
-        if None not in (current, total) and total > 0:
+        if None not in (current, total):
             self.set_fraction(1.0 * current / total)
         while gtk.events_pending():
             gtk.main_iteration()

